Please see [https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/create-patch](https://docs.mlcommons.org/cm4mlops/scripts/DevOps-automation/create-patch) for the documentation of this CM script.
